@@ -53,9 +53,14 @@ struct _JsonObject
 {
   GHashTable *members;
 
+  /* the members of the object, ordered in reverse */
+  GList *members_ordered;
+
   volatile gint ref_count;
 };
 
+G_CONST_RETURN gchar *json_node_type_get_name (JsonNodeType node_type);
+
 G_END_DECLS
 
 #endif /* __JSON_TYPES_PRIVATE_H__ */
